@@ -1,40 +1,44 @@
 package PNI::Node;
 use strict;
 use warnings;
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 use base 'PNI::Item';
 use PNI::Slot::In;
 use PNI::Slot::Out;
 
 sub new {
+
+    # ignore the first parameter since the node class depends
+    # on type parameter, see below
     shift;    # my $class
+
+    # $arg can be empty if you want an empty node
     my $arg = {@_};
 
     # type parameter is optional
-    my $node_type = $arg->{type};
-    my $node_class;
+    my $type = $arg->{type};
+    my $class;
 
     # if a type is specified, try to require the corresponding class
-    if ( defined $node_type ) {
-        $node_class = __PACKAGE__ . '::' . $node_type;
-        ( my $node_path = $node_class . '.pm' ) =~ s=::=/=g;
-        eval { require $node_path } or return;
+    if ( defined $type ) {
+        $class = __PACKAGE__ . '::' . $type;
+        ( my $path = $class . '.pm' ) =~ s=::=/=g;
+        eval { require $path } or return;
     }
 
     # otherwise build a generic empty node you can decorate later
     else {
-        $node_class = __PACKAGE__;
+        $class = __PACKAGE__;
     }
 
-    my $self = PNI::Item::new($node_class);
+    # seems better than $class->SUPER::new
+    my $self = PNI::Item::new($class);
 
     $self->add( 'inputs'  => {} );
     $self->add( 'outputs' => {} );
-    $self->init;
 
-    # at this point the node is created, so you can add it in a hierarchy
-    my $hierarchy = $arg->{hierarchy} or return;
-    $self->add( hierarchy => $hierarchy );
+    # at this point the node is created, so you can initialize it
+    $self->init or return;
 
     return $self;
 }
@@ -49,7 +53,7 @@ sub add_input {
     my $input = PNI::Slot::In->new( node => $self, name => $input_name, @_ )
       or return;
     $self->get('inputs')->{ $input->get_name } = $input;
-    return 1;
+    return $input;
 }
 
 sub add_output {
@@ -62,7 +66,7 @@ sub add_output {
     my $output = PNI::Slot::Out->new( node => $self, name => $output_name, @_ )
       or return;
     $self->get('outputs')->{ $output->get_name } = $output;
-    return 1;
+    return $output;
 }
 
 sub del_input  { return 1; }
