@@ -1,16 +1,18 @@
 package PNI::Slot;
 use strict;
 use warnings;
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 use base 'PNI::Item';
 
 sub new {
     my $class = shift;
     my $arg = {@_} or return;
 
+    # node arg is required and it must be a PNI::Node
     my $node = $arg->{node} or return;
     $node->isa('PNI::Node') or return;
 
+    # name arg is required
     my $name = $arg->{name} or return;
 
     # data parameter can be undef
@@ -27,8 +29,6 @@ sub get_name {
     return shift->get('name');
 }
 
-sub set_name { }
-
 sub get_node {
     return shift->get('node');
 }
